==> ssp-center-api-0.0.17-lqs16-20170616.024328-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteAccountSettlementService.java <==
/**
 * Project Name:ssp-center-api
 * File Name:RemoteAccountSettlementService.java
 * Package Name:cn.com.duiba.tuia.ssp.center.api.remote
 * Date:2017年5月22日下午5:22:20
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.tuia.ssp.center.api.remote;

import java.util.List;

import cn.com.duiba.tuia.ssp.center.api.dto.AccountSettlementDto;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqUpdateCheckStatus;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:RemoteAccountSettlementService <br/>
 * Function: 用户结算数据. <br/>
 * Date:     2017年5月22日 下午5:22:20 <br/>
 * @author   guyan
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public interface RemoteAccountSettlementService {
    
    /**
     * 通过月账单IDS 查询结算数据
     * 
     * @param billIds
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<AccountSettlementDto>> getSettlementList(List<Long> appIds,List<String> curDates,Long mediaId);
    
    /**
     * 通过账单ID 查询结算数据信息
     *
     * @param billId
     * @return
     * @since JDK 1.6
     */
    DubboResult<AccountSettlementDto> getSettlementById(Long billId);
    
    /**
     * 通过月账单IDS 查询提现金额
     *
     * @param billIds
     * @return
     * @since JDK 1.6
     */
    DubboResult<Long> getSettlementAmountByIds(List<Long> appIds,List<String> curDates,Long mediaId);
    
    /**
     * 查询一条用户结算数据
     *
     * @param appId
     * @param curDate
     * @param mediaId
     * @return
     * @since JDK 1.6
     */
    DubboResult<AccountSettlementDto> getAccountSettlement(Long appId,String curDate,Long mediaId);

    /**
     * 通过月账单id，查询对应媒体提现总额
     */
    DubboResult<List<AccountSettlementDto>> selectOrderCashByReportIds(List<Long> reportIds);

    /**
     * 通过app id和年月查询对应的结算金额
     */
    DubboResult<AccountSettlementDto> selectByAppIdAndDate(Long appId, String curDate);

    /**
     * 插入媒体结算信息
     */
    DubboResult<Boolean> insert(AccountSettlementDto accountSettlementDto);

    /**
     * 更新结算信息
     */
    DubboResult<Boolean> update(AccountSettlementDto accountSettlementDto);

    /**
     * 通过App id和月份查询对应的结算后账单信息
     * 月份格式 YYYY-MM
     */
    DubboResult<AccountSettlementDto> getSettlementByAppAndMonth(Long appId,String settledDate);

    /**
     * 修改审核状态
     */
    DubboResult<Boolean> updateSettlementStatus(ReqUpdateCheckStatus req);
}

==> ssp-center-api-0.1.34-lqs1-20171201.124759-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteAccountSettlementService.java <==
/**
 * Project Name:ssp-center-api
 * File Name:RemoteAccountSettlementService.java
 * Package Name:cn.com.duiba.tuia.ssp.center.api.remote
 * Date:2017年5月22日下午5:22:20
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.tuia.ssp.center.api.remote;

import java.util.List;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.AccountSettlementDto;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqAccountMonthReportByPage;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqUpdateCheckStatus;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:RemoteAccountSettlementService <br/>
 * Function: 用户结算数据. <br/>
 * Date:     2017年5月22日 下午5:22:20 <br/>
 * @author   guyan
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
@AdvancedFeignClient
public interface RemoteAccountSettlementService {
    
    /**
     * 通过月账单IDS 查询结算数据
     * 
     * @param billIds
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<AccountSettlementDto>> getSettlementList(List<Long> appIds,List<String> curDates,Long mediaId);
    
    /**
     * 通过账单ID 查询结算数据信息
     *
     * @param billId
     * @return
     * @since JDK 1.6
     */
    DubboResult<AccountSettlementDto> getSettlementById(Long billId);
    
    /**
     * 通过月账单IDS 查询提现金额
     *
     * @param billIds
     * @return
     * @since JDK 1.6
     */
    DubboResult<Long> getSettlementAmountByIds(List<Long> appIds,List<String> curDates,Long mediaId);
    
    /**
     * 查询一条用户结算数据
     *
     * @param appId
     * @param curDate
     * @param mediaId
     * @return
     * @since JDK 1.6
     */
    DubboResult<AccountSettlementDto> getAccountSettlement(Long appId,String curDate,Long mediaId);

    /**
     * 通过月账单id，查询对应媒体提现总额
     */
    DubboResult<List<AccountSettlementDto>> selectOrderCashByReportIds(List<Long> reportIds);

    /**
     * 通过app id和年月查询对应的结算金额
     */
    DubboResult<AccountSettlementDto> selectByAppIdAndDate(Long appId, String curDate);

    /**
     * 插入媒体结算信息
     */
    DubboResult<Boolean> insert(AccountSettlementDto accountSettlementDto);

    /**
     * 更新结算信息
     */
    DubboResult<Boolean> update(AccountSettlementDto accountSettlementDto);

    /**
     * 通过App id和月份查询对应的结算后账单信息
     * 月份格式 YYYY-MM
     */
    DubboResult<AccountSettlementDto> getSettlementByAppAndMonth(Long appId,String settledDate);

    /**
     * 修改审核状态
     */
    DubboResult<Boolean> updateSettlementStatus(ReqUpdateCheckStatus req);
    
    /**
     * 
     * getSettlementListByIds:(查询结算单信息). <br/>
     *
     * @author guyan
     * @param appIds
     * @param curDates
     * @param mediaId
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<AccountSettlementDto>> getSettlementListByIds(List<Long> appIds,List<String> curDates,Long mediaId);
    
    /**
     * 
     * selectAccountSettlementSum:(查询结算单总计). <br/>
     *
     * @author guyan
     * @param req
     * @return
     * @since JDK 1.6
     */
    DubboResult<Long> selectAccountSettlementSum(ReqAccountMonthReportByPage req);
}
